var searchData=
[
  ['_5f_5fgetattr_5f_5f',['__getattr__',['../classplplotc_1_1PLGraphicsIn.html#aa897e50c884f2528550fbb044f8591ed',1,'plplotc.PLGraphicsIn.__getattr__()'],['../classplplotc__fixed_1_1PLGraphicsIn.html#a62d891e685fe859226951d08750395ae',1,'plplotc_fixed.PLGraphicsIn.__getattr__()']]],
  ['_5f_5fpad0_5f_5f',['__pad0__',['../classplplot.html#a99e3a2f7f971b4759590ff8f417e4d4e',1,'plplot']]],
  ['_5f_5frepr_5f_5f',['__repr__',['../classplplotc_1_1PLGraphicsIn.html#acc43866fc01db36b65d4828ceecede26',1,'plplotc.PLGraphicsIn.__repr__()'],['../classplplotc__fixed_1_1PLGraphicsIn.html#ab2afa78a2d4ebe7ebf066aa8e0207afb',1,'plplotc_fixed.PLGraphicsIn.__repr__()']]],
  ['_5f_5fsetattr_5f_5f',['__setattr__',['../classplplotc_1_1PLGraphicsIn.html#aa5f51ef0e260d2c9b163478f96166fdc',1,'plplotc.PLGraphicsIn.__setattr__()'],['../classplplotc__fixed_1_1PLGraphicsIn.html#a6026296f3aa08a4ebc7768c3e1ef17c4',1,'plplotc_fixed.PLGraphicsIn.__setattr__()']]],
  ['_5f_5fswig_5fdestroy_5f_5f',['__swig_destroy__',['../classplplotc_1_1PLGraphicsIn.html#ad52c629ff1b60f10bf839a8fbf25be70',1,'plplotc.PLGraphicsIn.__swig_destroy__()'],['../classplplotc__fixed_1_1PLGraphicsIn.html#a845b1661e861eaad55d740fee2df1853',1,'plplotc_fixed.PLGraphicsIn.__swig_destroy__()']]],
  ['_5f_5fswig_5fgetmethods_5f_5f',['__swig_getmethods__',['../classplplotc_1_1PLGraphicsIn.html#ab393dd4d81eab0f2a717271cfb1fc8a2',1,'plplotc.PLGraphicsIn.__swig_getmethods__()'],['../classplplotc__fixed_1_1PLGraphicsIn.html#a2cd131a8cb1851907ecc2246ab41a849',1,'plplotc_fixed.PLGraphicsIn.__swig_getmethods__()']]],
  ['_5f_5fswig_5fsetmethods_5f_5f',['__swig_setmethods__',['../classplplotc_1_1PLGraphicsIn.html#ae0af3fc699016249917fdfe606a3582e',1,'plplotc.PLGraphicsIn.__swig_setmethods__()'],['../classplplotc__fixed_1_1PLGraphicsIn.html#afe0e78d2d8e5026f460145bd3a8f680f',1,'plplotc_fixed.PLGraphicsIn.__swig_setmethods__()']]],
  ['_5fnewclass',['_newclass',['../namespaceplplotc.html#aa3f0769fc515941a73a96a2993a88e07',1,'plplotc._newclass()'],['../namespaceplplotc__fixed.html#ad006db81e1716702eb3d05794232ebb0',1,'plplotc_fixed._newclass()']]],
  ['_5fnx',['_nx',['../classContourable__Data.html#a81d1eb26e390b2a3b0c3ab0ada6960c0',1,'Contourable_Data']]],
  ['_5fny',['_ny',['../classContourable__Data.html#aa548943e7e73bc001c0d7f162106ac9e',1,'Contourable_Data']]],
  ['_5fplplotc',['_plplotc',['../namespaceplplotc.html#ac3c13b77c76baac12d69958f88eca623',1,'plplotc._plplotc()'],['../namespaceplplotc__fixed.html#a4183603368371b1d7d897cd4aa6cd389',1,'plplotc_fixed._plplotc()']]],
  ['_5fswigc_5f_5fp_5fchar',['_swigc__p_char',['../plplotluacLUA__wrap_8c.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a8848127146fe0444e2fe3183a15b67f5',1,'_swigc__p_char():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5fdouble',['_swigc__p_double',['../plplotluacLUA__wrap_8c.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a28b7f0e03111f37524cf093e3a8a2304',1,'_swigc__p_double():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5ff_5fdouble_5fdouble_5f_5fint',['_swigc__p_f_double_double__int',['../plplotluacLUA__wrap_8c.html#a207f66749bdba90b94fc94339a002520',1,'_swigc__p_f_double_double__int():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a207f66749bdba90b94fc94339a002520',1,'_swigc__p_f_double_double__int():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5ff_5fdouble_5fdouble_5fp_5fdouble_5fp_5fdouble_5fp_5fvoid_5f_5fvoid',['_swigc__p_f_double_double_p_double_p_double_p_void__void',['../plplotluacLUA__wrap_8c.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a3f4c37068cdd295d0dafa913f043216e',1,'_swigc__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5ff_5fint_5fdouble_5fp_5fchar_5fint_5fp_5fvoid_5f_5fvoid',['_swigc__p_f_int_double_p_char_int_p_void__void',['../plplotluacLUA__wrap_8c.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#abd7eee4930f48e2326a9df35e20f0bba',1,'_swigc__p_f_int_double_p_char_int_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5ff_5fint_5fp_5fdouble_5fp_5fdouble_5f_5fvoid',['_swigc__p_f_int_p_double_p_double__void',['../plplotluacLUA__wrap_8c.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a5c2379fb009e6c97a5de4731c20e4283',1,'_swigc__p_f_int_p_double_p_double__void():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5ff_5fint_5fp_5fq_5fconst_5f_5fdouble_5fp_5fq_5fconst_5f_5fdouble_5f_5fvoid',['_swigc__p_f_int_p_q_const__double_p_q_const__double__void',['../plplotluacLUA__wrap_8c.html#af6625b2b7918b35eddbed9053fad7905',1,'_swigc__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#af6625b2b7918b35eddbed9053fad7905',1,'_swigc__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5fint',['_swigc__p_int',['../plplotluacLUA__wrap_8c.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a216d8b24b856092e2e65830ef290159b',1,'_swigc__p_int():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5fp_5fchar',['_swigc__p_p_char',['../plplotluacLUA__wrap_8c.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#adf82b09513b48dd2275acc2fa74711b7',1,'_swigc__p_p_char():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5fp_5fdouble',['_swigc__p_p_double',['../plplotluacLUA__wrap_8c.html#a8ef572e7214cb0eedcc6419377664472',1,'_swigc__p_p_double():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a8ef572e7214cb0eedcc6419377664472',1,'_swigc__p_p_double():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5fplcgrid',['_swigc__p_PLcGrid',['../plplotcPYTHON__wrap_8c.html#ab71600ff158f81ba0f2ad17add084b68',1,'plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5fplcgrid2',['_swigc__p_PLcGrid2',['../plplotcPYTHON__wrap_8c.html#a15ad6cd2c38c0be50be771105a0e60a6',1,'plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5fplgraphicsin',['_swigc__p_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#adbc9470f42e7e3c0a2adab2df09b950d',1,'_swigc__p_PLGraphicsIn():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigc_5f_5fp_5funsigned_5fint',['_swigc__p_unsigned_int',['../plplotluacLUA__wrap_8c.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aba9e61dc970ecfa60bf8a90276b1daa9',1,'_swigc__p_unsigned_int():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5fchar',['_swigt__p_char',['../plplotluacLUA__wrap_8c.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae66f44191f70db7b9634a8321766c840',1,'_swigt__p_char():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5fdouble',['_swigt__p_double',['../plplotluacLUA__wrap_8c.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a650096f8d16b87549437da125768b407',1,'_swigt__p_double():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5ff_5fdouble_5fdouble_5f_5fint',['_swigt__p_f_double_double__int',['../plplotluacLUA__wrap_8c.html#aa99dba7c5dc196a6edb638363e104be7',1,'_swigt__p_f_double_double__int():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#aa99dba7c5dc196a6edb638363e104be7',1,'_swigt__p_f_double_double__int():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5ff_5fdouble_5fdouble_5fp_5fdouble_5fp_5fdouble_5fp_5fvoid_5f_5fvoid',['_swigt__p_f_double_double_p_double_p_double_p_void__void',['../plplotluacLUA__wrap_8c.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a169d330528354eea0e80046288f7a240',1,'_swigt__p_f_double_double_p_double_p_double_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5ff_5fint_5fdouble_5fp_5fchar_5fint_5fp_5fvoid_5f_5fvoid',['_swigt__p_f_int_double_p_char_int_p_void__void',['../plplotluacLUA__wrap_8c.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ad192a829bb4110f62a13c396ab965321',1,'_swigt__p_f_int_double_p_char_int_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5ff_5fint_5fp_5fdouble_5fp_5fdouble_5f_5fvoid',['_swigt__p_f_int_p_double_p_double__void',['../plplotluacLUA__wrap_8c.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac93b2bfcffa54c72401ce0fe924336ef',1,'_swigt__p_f_int_p_double_p_double__void():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5ff_5fint_5fp_5fq_5fconst_5f_5fdouble_5fp_5fq_5fconst_5f_5fdouble_5f_5fvoid',['_swigt__p_f_int_p_q_const__double_p_q_const__double__void',['../plplotluacLUA__wrap_8c.html#a8a3b05af198a366e7d91148da9aa0695',1,'_swigt__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a8a3b05af198a366e7d91148da9aa0695',1,'_swigt__p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5fint',['_swigt__p_int',['../plplotluacLUA__wrap_8c.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#abb18e7711ddb7deeaf40f89dd6643b2c',1,'_swigt__p_int():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5fp_5fchar',['_swigt__p_p_char',['../plplotluacLUA__wrap_8c.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a701773c68706ee07319dc186a10ec151',1,'_swigt__p_p_char():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5fp_5fdouble',['_swigt__p_p_double',['../plplotluacLUA__wrap_8c.html#a7142a8246b533266bb0a1ec0e07d0516',1,'_swigt__p_p_double():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a7142a8246b533266bb0a1ec0e07d0516',1,'_swigt__p_p_double():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5fplcgrid',['_swigt__p_PLcGrid',['../plplotcPYTHON__wrap_8c.html#ac62d4edffb73674c8eb44ee0965094fc',1,'plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5fplcgrid2',['_swigt__p_PLcGrid2',['../plplotcPYTHON__wrap_8c.html#aefc05597d3afa2cf5e60f169e7326c10',1,'plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5fplgraphicsin',['_swigt__p_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aa7423ef65fc1e3d9cc8e9acb90b31531',1,'_swigt__p_PLGraphicsIn():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fswigt_5f_5fp_5funsigned_5fint',['_swigt__p_unsigned_int',['../plplotluacLUA__wrap_8c.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac758895aa5c2bb2a384d76af7fc77b2c',1,'_swigt__p_unsigned_int():&#160;plplotcPYTHON_wrap.c']]],
  ['_5fwrap_5fclass_5fplgraphicsin',['_wrap_class_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#af535aeb8e20ec55a72edebec41daf497',1,'_wrap_class_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ab1150b7ebddb76d9e0884b3300ef4edd',1,'_wrap_class_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpl_5fsetcontlabelformat_5ftexinfo',['_wrap_pl_setcontlabelformat_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a76edcc2158f8896af1584385985b7baa',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpl_5fsetcontlabelparam_5ftexinfo',['_wrap_pl_setcontlabelparam_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7d69e72e6fa91ee737d5b6f20af8bc4a',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpladv_5ftexinfo',['_wrap_pladv_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a0930e7ca7a2b3564c5c9c604eaec6799',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplarc_5ftexinfo',['_wrap_plarc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a3554ac4d6122a21636f13e1b80d54c61',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplaxes_5ftexinfo',['_wrap_plaxes_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a65dd1b401de58c03f4bc7124f914579d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplbin_5ftexinfo',['_wrap_plbin_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a22bea9a6b4dffb3f31bfdef626e3f00c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplbop_5ftexinfo',['_wrap_plbop_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae5c0ac10e2630787663c19ee546f6bc5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplbox3_5ftexinfo',['_wrap_plbox3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a03cfd966415718f4fffecb9193d53b41',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplbox_5ftexinfo',['_wrap_plbox_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab853cfe7ce775d3882971390e4584627',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplbtime_5ftexinfo',['_wrap_plbtime_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5b30d9dc4ea6486f01114cbc1de0126b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplcalc_5fworld_5ftexinfo',['_wrap_plcalc_world_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a0a2c258f6dcd3cdf6513734422990176',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplclear_5ftexinfo',['_wrap_plclear_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac5c6e7b86c86dc0737dac02df648b105',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplcol0_5ftexinfo',['_wrap_plcol0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1761de57100c0d31a25fb0f2b1d89004',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplcol1_5ftexinfo',['_wrap_plcol1_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aeec4aea06c98bb36d5625d3f903fe485',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplcolorbar_5ftexinfo',['_wrap_plcolorbar_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#afab0eefbdde0ae7077e59fc76995ac71',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplconfigtime_5ftexinfo',['_wrap_plconfigtime_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7216a1ee562155fabc49e88fdd64746c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplcont_5ftexinfo',['_wrap_plcont_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aeb5e286e22dd49a5c53d06e3e0d49913',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplcpstrm_5ftexinfo',['_wrap_plcpstrm_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a83a26a27ebfa2aba10d7710d34d5dbef',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplctime_5ftexinfo',['_wrap_plctime_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aec230e51536ce9702385accbe5d43823',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplend1_5ftexinfo',['_wrap_plend1_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a37ce505d80c4ed872fcc4634362e344a',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplend_5ftexinfo',['_wrap_plend_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a12b6a75136ddfbc0b72065f15381c86f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplenv0_5ftexinfo',['_wrap_plenv0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a44c4b472eadb4005011215b1c2fee6dc',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplenv_5ftexinfo',['_wrap_plenv_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4645cc4e3a33879ba6c841dc073d5d47',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpleop_5ftexinfo',['_wrap_pleop_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab5fb59ba5c25d13808a7d038cffc1a77',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplerrx_5ftexinfo',['_wrap_plerrx_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5f3b1d55b43a0cc5aabf458c26d3c641',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplerry_5ftexinfo',['_wrap_plerry_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#af8c15263209289b0773cd78380263f1d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplfamadv_5ftexinfo',['_wrap_plfamadv_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a178609368d50ddbbf167108ef7ae23d6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplfill3_5ftexinfo',['_wrap_plfill3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab13b34305802ebe00f7d04cac290f626',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplfill_5ftexinfo',['_wrap_plfill_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a2c6311c6b5b14d92c71fd956ed2019d9',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplflush_5ftexinfo',['_wrap_plflush_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1c92f63eaba5d356a9351507ddabb963',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplfont_5ftexinfo',['_wrap_plfont_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad28e38730730fd3fdb27e7c360fed5a5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplfontld_5ftexinfo',['_wrap_plfontld_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a79d9f72aeda3ed9642cd42ccff4eadd8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgchr_5ftexinfo',['_wrap_plgchr_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4f2bcefca98606b5697148b740127ce6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgcmap1_5frange_5ftexinfo',['_wrap_plgcmap1_range_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a353b601cfe71ab0e29c3426679437ed3',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgcol0_5ftexinfo',['_wrap_plgcol0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9356bc1d7e75b8b4e89eeed4e9837b06',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgcol0a_5ftexinfo',['_wrap_plgcol0a_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a33ff8a9ce80ad074a212665248b43359',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgcolbg_5ftexinfo',['_wrap_plgcolbg_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad59523ca68afcfbf0139250017683a37',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgcolbga_5ftexinfo',['_wrap_plgcolbga_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a3864274b76f1cfdbffdfed55c44fdba0',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgcompression_5ftexinfo',['_wrap_plgcompression_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a2b95f19b0d4d9ddabac884ae34d484c1',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgdev_5ftexinfo',['_wrap_plgdev_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1714980fbc94d3d0899550854c1d4d27',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgdidev_5ftexinfo',['_wrap_plgdidev_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ade375d0038cb6f2024a244e0ecd34ff0',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgdiori_5ftexinfo',['_wrap_plgdiori_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a58b681a2e82a2a4b6abed90d18e7cfe2',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgdiplt_5ftexinfo',['_wrap_plgdiplt_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a81af5d9d150d7f45682f903e3f0bb1a2',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgetcursor_5ftexinfo',['_wrap_plGetCursor_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#afd49d641e72ee51611cf1a5b51691cda',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgfam_5ftexinfo',['_wrap_plgfam_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5dbd9d3f9accae4a39c873006db5a504',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgfci_5ftexinfo',['_wrap_plgfci_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9f4997b65360e1bb8940cf15e8cdb3d7',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgfnam_5ftexinfo',['_wrap_plgfnam_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a448e50f9abb019758b9cb1b64c95f335',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgfont_5ftexinfo',['_wrap_plgfont_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a68c9310ea86620c6eb342fed30f0732d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplglevel_5ftexinfo',['_wrap_plglevel_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a999fb467b38d42930630c1283b35e7c3',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgpage_5ftexinfo',['_wrap_plgpage_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a3cb56c1e02dd0a800320bb3ae92b95e0',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgra_5ftexinfo',['_wrap_plgra_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae9edd6bffb84c56c14b227b54cee149d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgradient_5ftexinfo',['_wrap_plgradient_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#afc8bbf76f9aed0216a7dc7e73d2556d7',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgriddata_5ftexinfo',['_wrap_plgriddata_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac0192a83fc06dbecaf696b811eba49c1',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgspa_5ftexinfo',['_wrap_plgspa_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad6c1830b23066ec1272e75a6da3e32e3',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgstrm_5ftexinfo',['_wrap_plgstrm_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7198af1b4b98936047474e5f9f9a85aa',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgver_5ftexinfo',['_wrap_plgver_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a531eb694c170e1674dcaa9993e649de8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgvpd_5ftexinfo',['_wrap_plgvpd_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa40eeba571a52c1d722072f4dcc52cce',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgvpw_5ftexinfo',['_wrap_plgvpw_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6817eac6c54e9236624357ee3d5ecf63',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgxax_5ftexinfo',['_wrap_plgxax_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a77cd39a79393cb74c8ee81fb518571fe',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgyax_5ftexinfo',['_wrap_plgyax_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab7ff8eece1983c1346b546d727c534ac',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplgzax_5ftexinfo',['_wrap_plgzax_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a730dc323aa59640537133acd57cff60d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplhist_5ftexinfo',['_wrap_plhist_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aea461967543b0664b4f8e47740e9df46',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplhlsrgb_5ftexinfo',['_wrap_plhlsrgb_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa236c6bec1399905d39e8576ee4d6916',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplimagefr_5ftexinfo',['_wrap_plimagefr_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aced4dd5e41a58f1d126a0332d4179cef',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplinit_5ftexinfo',['_wrap_plinit_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7975d40886664c1c53d41fdedf449100',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpljoin_5ftexinfo',['_wrap_pljoin_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad07a9c4fcac378014e82375a664f6961',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpllab_5ftexinfo',['_wrap_pllab_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab9cde54baf0c8d14ca631917658a63e2',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpllegend_5ftexinfo',['_wrap_pllegend_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa09b24d0f8cd0f15548d833395b67b80',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpllightsource_5ftexinfo',['_wrap_pllightsource_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a2f2b0548e3a20888a7a71eea0a42c0a8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplline3_5ftexinfo',['_wrap_plline3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad81af41f841a15e9f5582bfe13622031',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplline_5ftexinfo',['_wrap_plline_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a73ac1d462f6994ffbd1a6f29aeecea44',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpllsty_5ftexinfo',['_wrap_pllsty_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a705e6d891cc869a85e78ae597f6304eb',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmap_5ftexinfo',['_wrap_plmap_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a61485d75cd2c7bf96f766343011586a5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmapfill_5ftexinfo',['_wrap_plmapfill_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a653c01bc6b35fb020c1db2c8aa85c223',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmapline_5ftexinfo',['_wrap_plmapline_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7c2b14e1e4bb6e5ec4faa64df9c4112b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmapstring_5ftexinfo',['_wrap_plmapstring_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a47e9a99e16ac455df40cd578a3abdfa1',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmaptex_5ftexinfo',['_wrap_plmaptex_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#adb7310118f8750ab8cc0b6c73de0f209',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmeridians_5ftexinfo',['_wrap_plmeridians_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1a8b540981e35670894f9eda38d00967',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmesh_5ftexinfo',['_wrap_plmesh_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6387ee3c522f6fde37faac6ef9f67f9b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmeshc_5ftexinfo',['_wrap_plmeshc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a05986bd52600fc7e2d9896a1faa890a6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmkstrm_5ftexinfo',['_wrap_plmkstrm_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a0c447aec75278270bc33c5b4af2f4546',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmtex3_5ftexinfo',['_wrap_plmtex3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa53274e1db64febf0e9201f075116861',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplmtex_5ftexinfo',['_wrap_plmtex_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6132d587658e5f9b5d686120e71b569a',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplot3d_5ftexinfo',['_wrap_plot3d_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a608b9473b4442fcf49fd460d7f9179c4',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplot3dc_5ftexinfo',['_wrap_plot3dc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a20c13f074fc6d38461de38d80311afef',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplot3dcl_5ftexinfo',['_wrap_plot3dcl_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad4b812626f9f2fcbebd472fc2793c384',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplparseopts_5ftexinfo',['_wrap_plparseopts_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad50938b99012a96743156299e0bf21b8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplpat_5ftexinfo',['_wrap_plpat_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad6de6f229517ee07ee9bc2f783db6f03',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplpath_5ftexinfo',['_wrap_plpath_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#accf0b523c4d903538d61bfd6edda9091',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplpoin3_5ftexinfo',['_wrap_plpoin3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a79cf81937918fa9edea3e124c3e84bb3',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplpoin_5ftexinfo',['_wrap_plpoin_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#abd1be9beb88110e4bcd4e36dee608301',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplpoly3_5ftexinfo',['_wrap_plpoly3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae041b99e6db05f04a39001f1a4282932',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplprec_5ftexinfo',['_wrap_plprec_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a3afd5038121b836cb51b40623b43f7b9',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplpsty_5ftexinfo',['_wrap_plpsty_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7b67e923c010c0a60ed0d9e0eda8683e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplptex3_5ftexinfo',['_wrap_plptex3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab1a29aadbc3eb3d90b5e5e52a3ac2321',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplptex_5ftexinfo',['_wrap_plptex_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a214c716a8eb03ca28cd1daa656a51650',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplrandd_5ftexinfo',['_wrap_plrandd_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a637e1bd31a2440ddae06f76d7c03c871',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplreplot_5ftexinfo',['_wrap_plreplot_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#af6ef84d78c14a04745d3a73715d97a6f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplrgbhls_5ftexinfo',['_wrap_plrgbhls_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6296bb6a836e3cf7673bc8533cf6846b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplschr_5ftexinfo',['_wrap_plschr_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a3cf50e8e8b15f005e72e05c189ffd28e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap0_5ftexinfo',['_wrap_plscmap0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a32e7f636b575d4a19d94cf97bc3fa16f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap0a_5ftexinfo',['_wrap_plscmap0a_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aead5dc1d59867f1a441bafa41c05cc28',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap0n_5ftexinfo',['_wrap_plscmap0n_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a65f48f537cc71a859d911ce533414569',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap1_5frange_5ftexinfo',['_wrap_plscmap1_range_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#afea08d524a1f34fc96f67b61079b4bfb',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap1_5ftexinfo',['_wrap_plscmap1_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a03cf65f0151e6b99793a43192b292470',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap1a_5ftexinfo',['_wrap_plscmap1a_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a8b6dc3c0af9c5fa2f654962909cd1d7e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap1l_5ftexinfo',['_wrap_plscmap1l_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aad41a3e50d11416b50ffcb5cccc1582c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap1la_5ftexinfo',['_wrap_plscmap1la_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae59ee61cf3dfd15c8ed257e871b2fb39',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscmap1n_5ftexinfo',['_wrap_plscmap1n_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6a3b745ab3c969de372e15b8cbda7f1e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscol0_5ftexinfo',['_wrap_plscol0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7db49bb07b4ef90aa3f0e991d467a69f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscol0a_5ftexinfo',['_wrap_plscol0a_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a891d46c37c7b12726c698a71f28c2788',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscolbg_5ftexinfo',['_wrap_plscolbg_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aed30ba9ab3b78b5b77ec6cd1571ae947',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscolbga_5ftexinfo',['_wrap_plscolbga_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a8906c0dc597f0f81a1cbb13c7e92109c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscolor_5ftexinfo',['_wrap_plscolor_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a2ba823335dd55140feb81ab76093b7ea',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplscompression_5ftexinfo',['_wrap_plscompression_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7d35dc8f3883c79dbf9608d7e4345135',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsdev_5ftexinfo',['_wrap_plsdev_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a775a1e3c7bf76df65906edb49e52b1a8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsdidev_5ftexinfo',['_wrap_plsdidev_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1c1f9e5264d87cc251d5e4617c5f07e3',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsdimap_5ftexinfo',['_wrap_plsdimap_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#abc9a6a743a4f72a3c7647df61094180c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsdiori_5ftexinfo',['_wrap_plsdiori_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a40ba5378f7ecd0a77edfa5c396cc2cbd',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsdiplt_5ftexinfo',['_wrap_plsdiplt_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a50749520e44c84e0ef9ef1afa9b1bea4',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsdiplz_5ftexinfo',['_wrap_plsdiplz_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6f2ed4442f119283aab6ea36998125e8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplseed_5ftexinfo',['_wrap_plseed_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5e2de7b0b9ccbe5be14689a94e377864',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsesc_5ftexinfo',['_wrap_plsesc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a67025781d17c02eb767767b652502182',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsetopt_5ftexinfo',['_wrap_plSetOpt_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a34164819ab4f46b57e27a35310a9ecda',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsfam_5ftexinfo',['_wrap_plsfam_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a52a50d1946285172f140211bba09a0ed',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsfci_5ftexinfo',['_wrap_plsfci_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4c3dcc40198bd902387211e9e20e62d7',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsfnam_5ftexinfo',['_wrap_plsfnam_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1f9dfda765c853242b80ce0b909bd171',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsfont_5ftexinfo',['_wrap_plsfont_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9fd95438850d30290a2696b0772d0943',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplshade_5ftexinfo',['_wrap_plshade_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a758878c62155eddc4ed09be54c46e585',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplshades_5ftexinfo',['_wrap_plshades_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a69ba285128deca5a9e650bb24066d5d6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplslabelfunc_5ftexinfo',['_wrap_plslabelfunc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4bf96847a6ca31044b2aaf3d1fc73ed2',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsmaj_5ftexinfo',['_wrap_plsmaj_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a26597a107bb38cbd32f14a1c046d4d52',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsmin_5ftexinfo',['_wrap_plsmin_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a98f1de558a442b07859ded8fa6e75326',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsori_5ftexinfo',['_wrap_plsori_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a505b76871e2dccf9a9676c8758a8718b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplspage_5ftexinfo',['_wrap_plspage_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#abb55eca59339b3713433b1f1819e1366',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplspal0_5ftexinfo',['_wrap_plspal0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac1963b0e515643598e09298ce61c240d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplspal1_5ftexinfo',['_wrap_plspal1_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aea94f71ceea2a14cfcafb14bf2caa5a6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplspause_5ftexinfo',['_wrap_plspause_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#abe99d015803bfe4e1572f467a353bcab',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsstrm_5ftexinfo',['_wrap_plsstrm_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a26cdfdf16086bb01ae0d51fee969151d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplssub_5ftexinfo',['_wrap_plssub_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a72998008cbd4608cb473bdde61c5477a',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplssym_5ftexinfo',['_wrap_plssym_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae6f1473af2fda478ead3cdcc4589fb05',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstar_5ftexinfo',['_wrap_plstar_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a94885ccc9f3eadf8f7ad961c17276ab3',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstart_5ftexinfo',['_wrap_plstart_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7d7e2eaf3d543753b1141048c633712b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstransform_5ftexinfo',['_wrap_plstransform_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5432d1e2f43bbc46b1a16b0315a28c61',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstring3_5ftexinfo',['_wrap_plstring3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a01915eb364f5a2a95916ca8119109fe8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstring_5ftexinfo',['_wrap_plstring_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#adc68738aa382c25d57692734b32a2b9f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstripa_5ftexinfo',['_wrap_plstripa_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad36ed9784b616cd56c2ba9776ae43a1d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstripc_5ftexinfo',['_wrap_plstripc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5caf9bb5f1ed7b311d939b522a017110',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstripd_5ftexinfo',['_wrap_plstripd_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a504a917ad44d08564b5997a62de04a63',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplstyl_5ftexinfo',['_wrap_plstyl_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6a4cd8420161832b90cbdba4a3533fa2',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsurf3d_5ftexinfo',['_wrap_plsurf3d_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a438a8ffdceab1a2e877ad3fb0615f84b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsurf3dl_5ftexinfo',['_wrap_plsurf3dl_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a63c84c9795f5f74f3e4cb372d9cd5176',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsvect_5ftexinfo',['_wrap_plsvect_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#af878cbcf61bf72976099a3399ba9b3ed',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsvpa_5ftexinfo',['_wrap_plsvpa_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a13530096b73487b7ce2c59c202c9e813',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsxax_5ftexinfo',['_wrap_plsxax_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa501592638bfa257b89ecef6f6887068',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsyax_5ftexinfo',['_wrap_plsyax_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#abc65beba588f31dc5a89c412114e63fe',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplsym_5ftexinfo',['_wrap_plsym_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a47130cee7b868a8868f0dd3d3ff864c5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplszax_5ftexinfo',['_wrap_plszax_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a00dedeeeecb76b07d977c39073cfa7a7',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpltext_5ftexinfo',['_wrap_pltext_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab734671e68f7032000f6c7e4850f7702',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fpltimefmt_5ftexinfo',['_wrap_pltimefmt_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a121d640a5966d8f1aa6fd19ddc7c5f22',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplvasp_5ftexinfo',['_wrap_plvasp_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae2f058e059af4134c502a7184eb2a3c4',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplvect_5ftexinfo',['_wrap_plvect_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a84f771c2d9c077a0eea911b1b1478a99',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplvpas_5ftexinfo',['_wrap_plvpas_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a070f675ffbc42d40983ac0c3fb62af28',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplvpor_5ftexinfo',['_wrap_plvpor_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a99d9ee043452c923b369ed08f16431e5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplvsta_5ftexinfo',['_wrap_plvsta_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a03917336709886d45c374df975694c86',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplw3d_5ftexinfo',['_wrap_plw3d_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae47738aaf075f83fed969c04cc6ea14b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplwidth_5ftexinfo',['_wrap_plwidth_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad1d01421c97390b60b7563a7de79d1d9',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplwind_5ftexinfo',['_wrap_plwind_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6ab5777aa4e65311f6f4cea99a621fcf',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['_5fwrap_5fplxormod_5ftexinfo',['_wrap_plxormod_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#acc2cdf6cc5b73e76054e0eeb883995d4',1,'plplot_octaveOCTAVE_wrap.cxx']]]
];
